Crate jito_restaking_core

Crate jito_restaking_core 

Modules

config
Global configuration account for the restaking program
discriminators
ncn
The NCN (Node Consensus Network) account is a program-owned account that represents a network of nodes that participate in consensus. The NCN account is used to manage the operators, vaults, and slashers that are associated with the network.
ncn_operator_state
ncn_vault_slasher_ticket
The NcnVaultSlasherTicket tracks the opting-in of a slasher to a particular vault. The NcnVaultSlasherTicket can be activated and deactivated over time by the NCN slasher admin.
ncn_vault_ticket
The NcnVaultTicket tracks the state of a node consensus network opting-in to a vault. The NcnVaultTicket can be activated and deactivated over time by the NCN vault admin.
operator
The Operator account stores global information for a particular operator including the admin, voter, and the number of NCN and vault accounts.
operator_vault_ticket

Constants

MAX_FEE_BPS