Operator

Struct Operator 

pub struct Operator {
    pub base: Pubkey,
    pub admin: Pubkey,
    pub ncn_admin: Pubkey,
    pub vault_admin: Pubkey,
    pub delegate_admin: Pubkey,
    pub metadata_admin: Pubkey,
    pub voter: Pubkey,
    pub operator_fee_bps: PodU16,
    pub bump: u8,
    /* private fields */
}
The Operator account stores global information for a particular operator including the admin, voter, and the number of NCN and vault accounts.

Fields

base: Pubkey

The base pubkey used as a seed for the PDA

admin: Pubkey

The admin pubkey

ncn_admin: Pubkey

The NCN admin can add and remove support for NCNs in the restaking protocol

vault_admin: Pubkey

The vault admin can add and remove support for vaults in the restaking protocol

delegate_admin: Pubkey

The delegate admin can delegate assets from the operator

metadata_admin: Pubkey

( For future use ) Authority to update the operators’s metadata

voter: Pubkey

The voter pubkey can be used as the voter for signing transactions for interacting with various NCN programs. NCNs can also opt for their own signing infrastructure.

operator_fee_bps: PodU16

The operator fee in basis points

bump: u8

The bump seed for the PDA

Implementations

Source

impl Operator

pub fn new( base: Pubkey, admin: Pubkey, index: u64, operator_fee_bps: u16, bump: u8, ) -> Self

Create a new Operator account

Arguments
  • base - The base account used as a PDA seed
  • admin - The admin of the Operator
  • index - The index of the Operator
  • bump - The bump seed for the PDA
pub fn index(&self) -> u64

pub fn ncn_count(&self) -> u64

pub fn vault_count(&self) -> u64

pub fn increment_ncn_count(&mut self) -> Result<(), RestakingError>

pub fn increment_vault_count(&mut self) -> Result<(), RestakingError>

pub fn check_admin(&self, admin: &Pubkey) -> Result<(), RestakingError>

Validates the admin account and ensures it matches the expected admin.

Arguments
  • admin - A reference to the Pubkey representing the admin Pubkey that is attempting to authorize the operation.
Returns
  • Result<(), RestakingError> - Returns Ok(()) if the admin account is valid.
Errors

This function will return a jito_restaking_sdk::error::RestakingError::OperatorAdminInvalid error in the following case:

  • The admin_info account’s public key does not match the expected admin public key stored in self.
pub fn check_delegate_admin( &self, delegate_admin: &Pubkey, ) -> Result<(), RestakingError>

Validates the delegate_admin account and ensures it matches the expected delegate_admin.

Arguments
  • delegate_admin_info - A reference to the Pubkey representing the delegate_admin Pubkey that is attempting to authorize the operation.
Returns
  • Result<(), RestakingError> - Returns Ok(()) if the delegate_admin account is valid.
Errors

This function will return a jito_restaking_sdk::error::RestakingError::OperatorDelegateAdminInvalid error in the following case:

  • The delegate_admin_info account’s public key does not match the expected admin public key stored in self.
pub fn update_secondary_admin(&mut self, old_admin: &Pubkey, new_admin: &Pubkey)

Replace all secondary admins that were equal to the old admin to the new admin

Arguments
  • old_admin - The old admin Pubkey
  • new_admin - The new admin Pubkey
pub fn seeds(base: &Pubkey) -> Vec<Vec<u8>>

Returns the seeds for the PDA

Arguments
  • base - The base account used as a PDA seed
Returns
  • Vec<Vec<u8>> - The seeds used to generate the PDA
pub fn find_program_address( program_id: &Pubkey, base: &Pubkey, ) -> (Pubkey, u8, Vec<Vec<u8>>)

Find the program address for the Operator account

Arguments
  • program_id - The program ID
  • base - The base account used as a PDA seed
Returns
  • Pubkey - The program address
  • u8 - The bump seed
  • Vec<Vec<u8>> - The seeds used to generate the PDA
pub fn load( program_id: &Pubkey, account: &AccountInfo<'_>, expect_writable: bool, ) -> Result<(), ProgramError>

Attempts to load the account as Operator, returning an error if it’s not valid.

Arguments
  • program_id - The program ID
  • account - The account to load the operator from
  • expect_writable - Whether the account should be writable
Returns
  • Result<(), ProgramError> - The result of the operation