The NCN (Node Consensus Network) account is a program-owned account that
represents a network of nodes that participate in consensus. The NCN
account is used to manage the operators, vaults, and slashers that are
associated with the network.
The NcnVaultSlasherTicket tracks the opting-in of a slasher to a particular vault.
The NcnVaultSlasherTicket can be activated and deactivated over time by the NCN slasher admin.
The NcnVaultTicket tracks the state of a node consensus network opting-in to a vault.
The NcnVaultTicket can be activated and deactivated over time by the NCN vault admin.